TxSubmitClientSolanaExt

Trait TxSubmitClientSolanaExt 

pub trait TxSubmitClientSolanaExt {
    // Required methods
    fn submit_unsigned<'life0, 'life1, 'async_trait, T>(
        &'life0 mut self,
        builder: TxBuilder,
        signers: &'life1 T,
        mode: SubmitMode,
    ) -> Pin<Box<dyn Future<Output = Result<SubmitResult, SolanaCompatSubmitError>> + Send + 'async_trait>>
       where T: Signers + Sync + ?Sized + 'async_trait,
             Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn submit_unsigned_with_context<'life0, 'life1, 'async_trait, T>(
        &'life0 mut self,
        builder: TxBuilder,
        signers: &'life1 T,
        mode: SubmitMode,
        context: TxSubmitContext,
    ) -> Pin<Box<dyn Future<Output = Result<SubmitResult, SolanaCompatSubmitError>> + Send + 'async_trait>>
       where T: Signers + Sync + ?Sized + 'async_trait,
             Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
    fn submit_transaction<'life0, 'async_trait>(
        &'life0 mut self,
        tx: VersionedTransaction,
        mode: SubmitMode,
    ) -> Pin<Box<dyn Future<Output = Result<SubmitResult, SolanaCompatSubmitError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn submit_transaction_with_context<'life0, 'async_trait>(
        &'life0 mut self,
        tx: VersionedTransaction,
        mode: SubmitMode,
        context: TxSubmitContext,
    ) -> Pin<Box<dyn Future<Output = Result<SubmitResult, SolanaCompatSubmitError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Solana-coupled convenience methods layered on top of sof-tx core byte submission.

Required Methods

fn submit_unsigned<'life0, 'life1, 'async_trait, T>( &'life0 mut self, builder: TxBuilder, signers: &'life1 T, mode: SubmitMode, ) -> Pin<Box<dyn Future<Output = Result<SubmitResult, SolanaCompatSubmitError>> + Send + 'async_trait>>
where T: Signers + Sync + ?Sized + 'async_trait, Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Builds, signs, and submits a transaction in one API call.

fn submit_unsigned_with_context<'life0, 'life1, 'async_trait, T>( &'life0 mut self, builder: TxBuilder, signers: &'life1 T, mode: SubmitMode, context: TxSubmitContext, ) -> Pin<Box<dyn Future<Output = Result<SubmitResult, SolanaCompatSubmitError>> + Send + 'async_trait>>
where T: Signers + Sync + ?Sized + 'async_trait, Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Builds, signs, and submits a transaction with explicit toxic-flow context.

fn submit_transaction<'life0, 'async_trait>( &'life0 mut self, tx: VersionedTransaction, mode: SubmitMode, ) -> Pin<Box<dyn Future<Output = Result<SubmitResult, SolanaCompatSubmitError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Submits one signed VersionedTransaction.

fn submit_transaction_with_context<'life0, 'async_trait>( &'life0 mut self, tx: VersionedTransaction, mode: SubmitMode, context: TxSubmitContext, ) -> Pin<Box<dyn Future<Output = Result<SubmitResult, SolanaCompatSubmitError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Submits one signed VersionedTransaction with explicit toxic-flow context.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl TxSubmitClientSolanaExt for TxSubmitClient

Source

fn submit_unsigned<'life0, 'life1, 'async_trait, T>( &'life0 mut self, builder: TxBuilder, signers: &'life1 T, mode: SubmitMode, ) -> Pin<Box<dyn Future<Output = Result<SubmitResult, SolanaCompatSubmitError>> + Send + 'async_trait>>
where T: Signers + Sync + ?Sized + 'async_trait, Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Source

fn submit_unsigned_with_context<'life0, 'life1, 'async_trait, T>( &'life0 mut self, builder: TxBuilder, signers: &'life1 T, mode: SubmitMode, context: TxSubmitContext, ) -> Pin<Box<dyn Future<Output = Result<SubmitResult, SolanaCompatSubmitError>> + Send + 'async_trait>>
where T: Signers + Sync + ?Sized + 'async_trait, Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Source

fn submit_transaction<'life0, 'async_trait>( &'life0 mut self, tx: VersionedTransaction, mode: SubmitMode, ) -> Pin<Box<dyn Future<Output = Result<SubmitResult, SolanaCompatSubmitError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Source

fn submit_transaction_with_context<'life0, 'async_trait>( &'life0 mut self, tx: VersionedTransaction, mode: SubmitMode, context: TxSubmitContext, ) -> Pin<Box<dyn Future<Output = Result<SubmitResult, SolanaCompatSubmitError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Implementors